==> hook-form-react-1.0.15.tgz: package/src/provider/FormContext.tsx <==
/* eslint-disable react/display-name */
import {
  createContext,
  Dispatch,
  PropsWithChildren,
  SetStateAction,
} from 'react';

import { DataTypeSingle } from '../types/types';

export type FormContextType = {
  name: string;
  data: object;
  updateField?: (field: string, value: unknown) => void;
  getFieldValue: (field: string) => DataTypeSingle;
  getData: () => object;
  setData?: Dispatch<SetStateAction<object>>;
  errors: Record<string, string>;
  setErrors?: Dispatch<SetStateAction<Record<string, string>>>;
  getError: (field: string) => string;
};

export const FormContext = createContext<FormContextType>({
  name: '',
  data: {},
  getFieldValue: () => undefined,
  getError: () => undefined,
  getData: () => ({}),
  errors: {},
});

export interface ProviderProps<DataType> extends PropsWithChildren {
  name: string;
  getData: () => DataType;
  getFieldValue: (field: string) => DataTypeSingle;
  updateField: (field: string, value: never) => void;
  data: Partial<DataType>;
  setData: Dispatch<SetStateAction<DataType>>;
  errors: Record<string, string>;
  setErrors: Dispatch<SetStateAction<Record<string, string>>>;
  getError: (field: string) => string;
}

const Provider = <DataType extends object>({
  children,
  name,
  getData,
  updateField,
  getFieldValue,
  data,
  setData,
    setErrors,
    errors,
    getError
}: ProviderProps<DataType>) => {
  return (
    <FormContext.Provider
      value={{ name, getFieldValue, getData, updateField, data, setData, errors, setErrors, getError }}
    >
      {children}
    </FormContext.Provider>
  );
};

export default Provider;

==> hook-form-react-1.0.17.tgz: package/src/provider/FormContext.tsx <==
import {
  createContext,
  Dispatch,
  PropsWithChildren,
  SetStateAction,
} from 'react';

import { DataTypeSingle } from '../types';

export type FormContextType = {
  data: object;
  updateField?: (field: string, value: unknown) => void;
  getFieldValue: (field: string) => DataTypeSingle;
  getData: () => object;
  setData?: Dispatch<SetStateAction<object>>;
  errors: Record<string, string>;
  setErrors?: Dispatch<SetStateAction<Record<string, string>>>;
  getError: (field: string) => string;
};

export const FormContext = createContext<FormContextType>({
  data: {},
  getFieldValue: () => undefined,
  getError: () => undefined,
  getData: () => ({}),
  errors: {},
});

export interface ProviderProps<DataType> extends PropsWithChildren {
  getData: () => DataType;
  getFieldValue: (field: string) => DataTypeSingle;
  updateField: (field: string, value: never) => void;
  data: Partial<DataType>;
  setData: Dispatch<SetStateAction<DataType>>;
  errors: Record<string, string>;
  setErrors: Dispatch<SetStateAction<Record<string, string>>>;
  getError: (field: string) => string;
}

const Provider = <DataType extends object>({
  children,
  getData,
  updateField,
  getFieldValue,
  data,
  setData,
    setErrors,
    errors,
    getError
}: ProviderProps<DataType>) => {
  return (
    <FormContext.Provider
      value={{ getFieldValue, getData, updateField, data, setData, errors, setErrors, getError }}
    >
      {children}
    </FormContext.Provider>
  );
};

export default Provider;
